TwoPartTileSet

Struct TwoPartTileSet 

pub struct TwoPartTileSet { /* private fields */ }
An implementation of TileSet that expects a hash map of tile foregrounds and a single background image.

This implementation automatically combines background and foreground on the fly. Also, it assumes “realistic” light for the rendered tiles (i.e. for rotated tiles, it mirrors the background, so it always seems like the light is coming from once source).

Implementations

Source

impl TwoPartTileSet

pub fn new( front: RgbaImage, tile_map: HashMap<Tile, RgbaImage>, ) -> Result<Self, TileSetCreationError>

Creates a new TwoPartTileSet instance using given background image and a map of tile foregrounds.